@@ -7,7 +7,7 @@
 #  define CMARK_NO_EXPORT
 #else
 #  ifndef CMARK_EXPORT
-#    ifdef libcmark_EXPORTS
+#    ifdef cmark_EXPORTS
         /* We are building this library */
 #      define CMARK_EXPORT __declspec(dllexport)
 #    else
